@@ -19,7 +19,7 @@
 
 from __future__ import absolute_import
 
-VERSION = (3, 3, 0, 1)
+VERSION = (3, 3, 0, 2)
 __version__ = ".".join(map(str, VERSION[0:4])) + "".join(VERSION[4:])
 __author__ = 'R Oudkerk / Python Software Foundation'
 __author_email__ = 'python-dev@python.org'
@@ -89,12 +89,12 @@ def Manager():
     return m
 
 
-def Pipe(duplex=True):
+def Pipe(duplex=True, rnonblock=False, wnonblock=False):
     '''
     Returns two connection object connected by a pipe
     '''
     from billiard.connection import Pipe
-    return Pipe(duplex)
+    return Pipe(duplex, rnonblock, wnonblock)
 
 
 def cpu_count():
