@@ -7,7 +7,7 @@ supports_exec = True
 try:
     import _winapi as win32
 except ImportError:  # pragma: no cover
-    win32 = None
+    win32 = None   # noqa
 
 if sys.platform.startswith("java"):
     _billiard = None
@@ -20,7 +20,7 @@ else:
     try:
         Connection = _billiard.Connection
     except AttributeError:  # Py3
-        from multiprocessing.connection import Connection  # noqa
+        from billiard.connection import Connection  # noqa
 
     PipeConnection = getattr(_billiard, "PipeConnection", None)
     if win32 is None:
