@@ -295,12 +295,16 @@ class Worker(Process):
         self._controlled_termination = True
         self.terminate()
 
+    def prepare_result(self, result):
+        return result
+
     def workloop(self, debug=debug, now=monotonic, pid=None):
         pid = pid or os.getpid()
         put = self.outq.put
         inqW_fd = self.inqW_fd
         synqW_fd = self.synqW_fd
         maxtasks = self.maxtasks
+        prepare_result = self.prepare_result
 
         wait_for_job = self.wait_for_job
         _wait_for_syn = self.wait_for_syn
@@ -333,7 +337,7 @@ class Worker(Process):
                     if not confirm:
                         continue  # received NACK
                 try:
-                    result = (True, fun(*args, **kwargs))
+                    result = (True, prepare_result(fun(*args, **kwargs)))
                 except Exception:
                     result = (False, ExceptionInfo())
                 try:
@@ -1070,7 +1074,7 @@ class Pool(object):
                         not getattr(worker, '_controlled_termination', False):
                     error(
                         'Process %r pid:%r exited with exitcode %r',
-                        worker.name, worker.pid, worker.exitcode, exc_info=1,
+                        worker.name, worker.pid, worker.exitcode, exc_info=0,
                     )
                 self.process_flush_queues(worker)
                 del self._pool[i]
@@ -1090,10 +1094,7 @@ class Pool(object):
                         exitcode = exitcodes[acked_by_gone]
                         if getattr(cleaned[acked_by_gone],
                                    '_job_terminated', False):
-                            try:
-                                raise Terminated(-exitcode)
-                            except Terminated:
-                                job._set(None, (False, ExceptionInfo()))
+                            job._set_terminated(exitcode)
                         else:
                             self.on_job_process_lost(
                                 job, acked_by_gone, exitcode,
@@ -1592,6 +1593,7 @@ class ApplyResult(object):
         self._error_callback = error_callback
         self._timeout_callback = timeout_callback
         self._timeout = timeout
+        self._terminated = None
         self._soft_timeout = soft_timeout
         self._lost_worker_timeout = lost_worker_timeout
         self._on_timeout_set = on_timeout_set
@@ -1627,6 +1629,15 @@ class ApplyResult(object):
     def discard(self):
         self._cache.pop(self._job, None)
 
+    def terminate(self, signum):
+        self._terminated = signum
+
+    def _set_terminated(self, signum=0):
+        try:
+            raise Terminated(-signum)
+        except Terminated:
+            self._set(None, (False, ExceptionInfo()))
+
     def worker_pids(self):
         return [self._worker_pid] if self._worker_pid else []
 
